@@ -4,7 +4,7 @@
 # Tradologics Python SDK
 # https://tradologics.com
 #
-# Copyright 2020-2021 Tradologics, Inc.
+# Copyright Tradologics, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,9 +19,10 @@
 # limitations under the License.
 
 
-__version__ = "0.0.14"
+__version__ = "0.0.19"
 
 __author__ = "Tradologics, Inc."
 
-from . import server, helpers, requests
-__all__ = ['helpers', 'server', 'requests', "__version__"]
+from . import server, helpers, requests, sandbox
+
+__all__ = ['helpers', 'server', 'requests', 'sandbox', '__version__']
